@@ -183,7 +183,8 @@ void AssetPanel::showMix(int cid, const std::shared_ptr<AssetParameterModel> &tr
         return;
     }
     clear();
-    m_switchAction->setVisible(true);
+    // There is only 1 audio composition, so hide switch combobox
+    m_switchAction->setVisible(transitionModel->getAssetId() != QLatin1String("mix"));
     m_titleAction->setVisible(false);
     m_assetTitle->clear();
     m_mixWidget->setVisible(true);
@@ -322,6 +323,7 @@ const QString AssetPanel::getStyleSheet()
     QColor hover_bg = scheme.decoration(KColorScheme::HoverColor).color();
     QColor light_bg = scheme.shade(KColorScheme::LightShade);
     QColor alt_bg = scheme.background(KColorScheme::NormalBackground).color();
+    QColor normal_bg = QApplication::palette().window().color();
 
     QString stylesheet;
 
@@ -376,10 +378,6 @@ const QString AssetPanel::getStyleSheet()
     // group editable labels
     stylesheet.append(QStringLiteral("MyEditableLabel { background-color: transparent; color: palette(bright-text); border-radius: 2px;border: 1px solid "
                                      "transparent;} MyEditableLabel:hover {border: 1px solid palette(highlight);} "));
-
-    // transparent qcombobox
-    stylesheet.append(QStringLiteral("QComboBox { background-color: transparent;} "));
-
     return stylesheet;
 }
 
