@@ -31,6 +31,7 @@
 #include "timeline2/view/timelinewidget.h"
 #include "timeline2/view/timelinecontroller.h"
 #include "timeline2/model/groupsmodel.hpp"
+#include "timeline2/model/clipmodel.hpp"
 #include "macros.hpp"
 
 #include "kdenlive_debug.h"
@@ -82,6 +83,11 @@ RemapView::RemapView(QWidget *parent)
     connect(&timer, &QTimer::timeout, this, &RemapView::reloadProducer);
 }
 
+bool RemapView::isInRange() const
+{
+    return m_bottomPosition != -1;
+}
+
 void RemapView::updateInPos(int pos)
 {
     if (m_currentKeyframe.second > -1) {
@@ -310,10 +316,15 @@ void RemapView::loadKeyframes(const QString &mapData)
         for (auto &s : str) {
             int pos = m_service->time_to_frames(s.section(QLatin1Char('='), 0, 0).toUtf8().constData());
             int val = GenTime(s.section(QLatin1Char('='), 1).toDouble()).frames(pCore->getCurrentFps());
+            // HACK: we always set last keyframe 1 frame after in MLT to ensure we have a correct last frame
+            if (s == str.constLast()) {
+                pos--;
+            }
             m_keyframes.insert(pos, val);
             m_duration = qMax(m_duration, pos - m_inFrame);
             m_duration = qMax(m_duration, val - m_inFrame);
         }
+
         if (m_keyframes.contains(m_currentKeyframe.first)) {
             bool isLast = m_currentKeyframe.first == m_keyframes.firstKey() || m_currentKeyframe.first == m_keyframes.lastKey();
             emit atKeyframe(true, isLast);
@@ -351,7 +362,6 @@ void RemapView::mouseMoveEvent(QMouseEvent *event)
             snapPos += m_offset;
             if (qAbs(snapPos - event->x()) < QApplication::startDragDistance()) {
                 pos = m_originalRange.second - m_inFrame;
-                qDebug()<<"///// FOUND A MATCH FOR OUT: "<<pos;
             }
         }
         if (pos == -1) {
@@ -561,6 +571,7 @@ void RemapView::mouseMoveEvent(QMouseEvent *event)
             }
         }
         if (m_moveKeyframeMode == CursorMoveBottom) {
+            pos = qMin(pos, m_keyframes.lastKey() - m_inFrame);
             if (pos != m_bottomPosition) {
                 m_bottomPosition = pos;
                 bool isKfr = m_keyframes.contains(m_bottomPosition + m_inFrame);
@@ -873,6 +884,7 @@ void RemapView::mousePressEvent(QMouseEvent *event)
             //m_selectedKeyframes.clear();
             //m_currentKeyframe = m_currentKeyframeOriginal = {-1,-1};
             m_moveKeyframeMode = CursorMoveBottom;
+            pos = qMin(pos, m_keyframes.lastKey() - m_inFrame);
             if (pos != m_bottomPosition) {
                 m_bottomPosition = pos;
                 bool isKfr = m_keyframes.contains(m_bottomPosition + m_inFrame);
@@ -1012,14 +1024,19 @@ void RemapView::slotSetPosition(int pos)
 
 void RemapView::slotSetBottomPosition(int pos)
 {
-    qDebug()<<"=== SETTING BOTTOM POS: "<<pos;
+    if (pos < 0 || pos + m_inFrame > m_keyframes.lastKey()) {
+        pos = -1;
+    }
     if (pos != m_bottomPosition) {
         m_bottomPosition = pos;
-        qDebug()<<"==== CURRENT: "<<(m_bottomPosition + m_inFrame)<<" = "<<m_keyframes.keys();
-        bool isKfr = m_keyframes.contains(m_bottomPosition + m_inFrame);
-        if (isKfr) {
-            bool isLast = m_bottomPosition + m_inFrame == m_keyframes.firstKey() || m_bottomPosition + m_inFrame == m_keyframes.lastKey();
-            emit atKeyframe(isKfr, isLast);
+        if (m_bottomPosition > -1) {
+            bool isKfr = m_keyframes.contains(m_bottomPosition + m_inFrame);
+            if (isKfr) {
+                bool isLast = m_bottomPosition + m_inFrame == m_keyframes.firstKey() || m_bottomPosition + m_inFrame == m_keyframes.lastKey();
+                emit atKeyframe(isKfr, isLast);
+            } else {
+                emit atKeyframe(false, false);
+            }
         } else {
             emit atKeyframe(false, false);
         }
@@ -1162,9 +1179,14 @@ const QString RemapView::getKeyframesData(QMap<int,int> keyframes) const
         keyframes = m_keyframes;
     }
     QMapIterator<int, int> i(keyframes);
+    int offset = 0;
     while (i.hasNext()) {
         i.next();
-        result << QString("%1=%2").arg(m_service->frames_to_time(i.key(), mlt_time_clock)).arg(GenTime(i.value(), pCore->getCurrentFps()).seconds());
+        if (i.key() == keyframes.lastKey()) {
+            // HACK: we always set last keyframe 1 frame after in MLT to ensure we have a correct last frame
+            offset = 1;
+        }
+        result << QString("%1=%2").arg(m_service->frames_to_time(i.key() + offset, mlt_time_clock)).arg(GenTime(i.value(), pCore->getCurrentFps()).seconds());
     }
     return result.join(QLatin1Char(';'));
 }
@@ -1589,7 +1611,6 @@ TimeRemap::TimeRemap(QWidget *parent)
     connect(pitch_compensate, &QCheckBox::toggled, this, &TimeRemap::switchRemapParam);
     connect(frame_blending, &QCheckBox::toggled, this, &TimeRemap::switchRemapParam);
     connect(m_view, &RemapView::updateMaxDuration, [this](int duration) {
-        int min = m_in->minimum();
         m_out->setRange(0, INT_MAX);
         //m_in->setRange(0, duration - 1);
     });
@@ -1601,25 +1622,32 @@ const QString &TimeRemap::currentClip() const
     return m_binId;
 }
 
-void TimeRemap::checkClipUpdate(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int>& roles)
+void TimeRemap::checkClipUpdate(const QModelIndex &topLeft, const QModelIndex &, const QVector<int>& roles)
 {
     int id = int(topLeft.internalId());
     if (m_cid != id || !roles.contains(TimelineModel::FinalMoveRole)) {
         return;
     }
     // Don't resize view if we are moving a keyframe
-    if (roles.contains(TimelineModel::DurationRole) && !m_view->movingKeyframe()) {
-        m_lastLength = pCore->getItemDuration({ObjectType::TimelineClip,m_cid});
+    if (!m_view->movingKeyframe()) {
+        int newDuration = pCore->getItemDuration({ObjectType::TimelineClip,m_cid});
+        // Check if the keyframes were modified by an external resize operation
+        std::shared_ptr<TimelineItemModel> model = pCore->window()->getCurrentTimeline()->controller()->getModel();
+        std::shared_ptr<ClipModel> clip = model->getClipPtr(m_cid);
+        QMap<QString,QString> values = clip->getRemapValues();
+        if (values.value(QLatin1String("map")) == m_view->getKeyframesData()) {
+            // Resize was triggered by our keyframe move, nothing to do
+            return;
+        }
+        // Reload keyframes
+        m_lastLength = newDuration;
+        m_view->m_remapLink->set("map", values.value(QLatin1String("map")).toUtf8().constData());
         int min = pCore->getItemIn({ObjectType::TimelineClip,m_cid});
         m_view->m_startPos = pCore->getItemPosition({ObjectType::TimelineClip,m_cid});
         m_in->setRange(0, m_view->m_maxLength - min);
         m_out->setRange(0, INT_MAX);
-        m_view->setDuration(nullptr, m_lastLength);
+        m_view->loadKeyframes(values.value(QLatin1String("map")));
         m_view->update();
-    } else if (roles.contains(TimelineModel::StartRole) && !m_view->movingKeyframe()) {
-        m_view->m_startPos = pCore->getItemPosition({ObjectType::TimelineClip,m_cid});
-        int duration = pCore->getItemDuration({ObjectType::TimelineClip,m_cid});
-        m_view->setDuration(nullptr, duration);
     }
 }
 
@@ -1642,14 +1670,11 @@ void TimeRemap::selectedClip(int cid)
         return;
     }
     m_view->m_remapLink.reset();
-    bool keyframesLoaded = false;
     connect(model.get(), &TimelineItemModel::dataChanged, this, &TimeRemap::checkClipUpdate);
     model->requestClipTimeRemap(cid);
     m_splitId = model->m_groups->getSplitPartner(cid);
     m_binId = model->getClipBinId(cid);
-    int min = pCore->getItemIn({ObjectType::TimelineClip,cid});
     m_lastLength = pCore->getItemDuration({ObjectType::TimelineClip,cid});
-    int max = min + m_lastLength;
     m_view->m_startPos = pCore->getItemPosition({ObjectType::TimelineClip,cid});
     std::shared_ptr<Mlt::Producer> prod = model->getClipProducer(cid);
     m_view->m_maxLength = prod->get_length();
@@ -1684,11 +1709,15 @@ void TimeRemap::selectedClip(int cid)
                     }
                     QString mapData(fromLink->get("map"));
                     m_view->loadKeyframes(mapData);
+                    if (mapData.isEmpty()) {
+                        // We are just adding the remap effect, set default params
+                        fromLink->set("pitch", 1);
+                        fromLink->set("image_mode", "nearest");
+                    }
                     QSignalBlocker bk(pitch_compensate);
                     QSignalBlocker bk2(frame_blending);
                     pitch_compensate->setChecked(fromLink->get_int("pitch") == 1);
-                    frame_blending->setChecked(fromLink->get("image_mode") == QLatin1String("blend"));
-                    keyframesLoaded = true;
+                    frame_blending->setChecked(fromLink->get("image_mode") != QLatin1String("nearest"));
                     setEnabled(true);
                     break;
                 }
@@ -1715,7 +1744,6 @@ void TimeRemap::selectedClip(int cid)
         }
     });
     m_seekConnection2 = connect(pCore->getMonitor(Kdenlive::ProjectMonitor), &Monitor::seekPosition, [this](int pos) {
-        //qDebug()<<"=== PROJECT SEEK: "<<pos<<", START: "<<m_view->m_startPos<<", MAPPED: "<<GenTime(m_view->m_remapLink->anim_get_double("map", pos - m_view->m_startPos)).frames(pCore->getCurrentFps());
         m_view->slotSetBottomPosition(pos - m_view->m_startPos);
     });
 }
@@ -1842,7 +1870,7 @@ void TimeRemap::updateKeyframesWithUndo(QMap<int,int>updatedKeyframes, QMap<int,
     bool usePitch = pitch_compensate->isChecked();
     bool useBlend = frame_blending->isChecked();
     bool hadPitch = m_view->m_remapLink->get_int("pitch") == 1;
-    bool hadBlend = m_view->m_remapLink->get("image_mode") == QLatin1String("blend");
+    bool hadBlend = m_view->m_remapLink->get("image_mode") != QLatin1String("nearest");
     bool durationChanged = updatedKeyframes.isEmpty() ? false : updatedKeyframes.lastKey() - pCore->getItemIn({ObjectType::TimelineClip,m_cid}) + 1 != pCore->getItemDuration({ObjectType::TimelineClip,m_cid});
     Fun undo = []() { return true; };
     Fun redo = []() { return true; };
@@ -1857,13 +1885,13 @@ void TimeRemap::updateKeyframesWithUndo(QMap<int,int>updatedKeyframes, QMap<int,
             link->set("map", oldKfData.toUtf8().constData());
         }
         link->set("pitch", hadPitch ? 1 : 0);
-        link->set("image_mode", hadBlend ? "blend" : "");
+        link->set("image_mode", hadBlend ? "blend" : "nearest");
         if (splitLink) {
             if (keyframesChanged) {
                 splitLink->set("map", oldKfData.toUtf8().constData());
             }
             splitLink->set("pitch", hadPitch ? 1 : 0);
-            splitLink->set("image_mode", hadBlend ? "blend" : "");
+            splitLink->set("image_mode", hadBlend ? "blend" : "nearest");
         }
         if (cid == m_cid) {
             QSignalBlocker bk(pitch_compensate);
@@ -1892,13 +1920,13 @@ void TimeRemap::updateKeyframesWithUndo(QMap<int,int>updatedKeyframes, QMap<int,
             link->set("map", newKfData.toUtf8().constData());
         }
         link->set("pitch", usePitch ? 1 : 0);
-        link->set("image_mode", useBlend ? "blend" : "");
+        link->set("image_mode", useBlend ? "blend" : "nearest");
         if (splitLink) {
             if (keyframesChanged) {
                 splitLink->set("map", newKfData.toUtf8().constData());
             }
             splitLink->set("pitch", usePitch ? 1 : 0);
-            splitLink->set("image_mode", useBlend ? "blend" : "");
+            splitLink->set("image_mode", useBlend ? "blend" : "nearest");
         }
         if (cid == m_cid) {
             QSignalBlocker bk(pitch_compensate);
@@ -1916,7 +1944,7 @@ void TimeRemap::updateKeyframesWithUndo(QMap<int,int>updatedKeyframes, QMap<int,
         return true;
     };
     if (durationChanged) {
-        int length = updatedKeyframes.lastKey() - m_view->m_inFrame;
+        int length = updatedKeyframes.lastKey() - m_view->m_inFrame + 1;
         std::shared_ptr<TimelineItemModel> model = pCore->window()->getCurrentTimeline()->controller()->getModel();
         model->requestItemResize(m_cid, length, true, true, undo, redo);
         if (m_splitId > 0) {
@@ -1933,6 +1961,11 @@ void TimeRemap::switchRemapParam()
     updateKeyframesWithUndo(QMap<int,int>(),QMap<int,int>());
 }
 
+bool TimeRemap::isInRange() const
+{
+    return m_cid != -1 && m_view->isInRange();
+}
+
 TimeRemap::~TimeRemap()
 {
     //delete m_previewTimer;
