@@ -346,7 +346,7 @@ void AbstractScopeWidget::mouseMoveEvent(QMouseEvent *event)
             // Detect the movement direction here.
             // This algorithm relies on the aspect ratio of dy/dx (size and signum).
             if (movement.manhattanLength() > m_rescaleMinDist) {
-                float diff = ((float)movement.y()) / (float)movement.x();
+                float diff = float(movement.y()) / movement.x();
 
                 if (std::fabs(diff) > m_rescaleVerticalThreshold || movement.x() == 0) {
                     m_rescaleDirection = North;
@@ -379,15 +379,15 @@ void AbstractScopeWidget::slotContextMenuRequested(const QPoint &pos)
 
 uint AbstractScopeWidget::calculateAccelFactorHUD(uint oldMseconds, uint)
 {
-    return std::ceil((float)oldMseconds * REALTIME_FPS / 1000);
+    return uint(std::ceil(float(oldMseconds) * REALTIME_FPS / 1000.f));
 }
 uint AbstractScopeWidget::calculateAccelFactorScope(uint oldMseconds, uint)
 {
-    return std::ceil((float)oldMseconds * REALTIME_FPS / 1000);
+    return uint(std::ceil(float(oldMseconds) * REALTIME_FPS / 1000.f));
 }
 uint AbstractScopeWidget::calculateAccelFactorBackground(uint oldMseconds, uint)
 {
-    return std::ceil((float)oldMseconds * REALTIME_FPS / 1000);
+    return uint(std::ceil(float(oldMseconds) * REALTIME_FPS / 1000.f));
 }
 
 ///// Slots /////
@@ -405,7 +405,7 @@ void AbstractScopeWidget::slotHUDRenderingFinished(uint mseconds, uint oldFactor
 
     if (m_aRealtime->isChecked()) {
         int accel;
-        accel = (int)calculateAccelFactorHUD(mseconds, oldFactor);
+        accel = int(calculateAccelFactorHUD(mseconds, oldFactor));
         if (m_accelFactorHUD < 1) {
             accel = 1;
         }
@@ -439,7 +439,7 @@ void AbstractScopeWidget::slotScopeRenderingFinished(uint mseconds, uint oldFact
     // Calculate the acceleration factor hint to get «realtime» updates.
     if (m_aRealtime->isChecked()) {
         int accel;
-        accel = (int)calculateAccelFactorScope(mseconds, oldFactor);
+        accel = int(calculateAccelFactorScope(mseconds, oldFactor));
         if (accel < 1) {
             // If mseconds happens to be 0.
             accel = 1;
@@ -472,7 +472,7 @@ void AbstractScopeWidget::slotBackgroundRenderingFinished(uint mseconds, uint ol
 
     if (m_aRealtime->isChecked()) {
         int accel;
-        accel = (int)calculateAccelFactorBackground(mseconds, oldFactor);
+        accel = int(calculateAccelFactorBackground(mseconds, oldFactor));
         if (m_accelFactorBackground < 1) {
             accel = 1;
         }
