@@ -30,27 +30,27 @@
 
 /** @brief This static class provides helper functions to manipulate Dom objects easily
  */
-
 namespace Xml {
 
 /** @brief Returns the content of a given tag within the current DomElement.
-   For example, if your @param element looks like <html><title>foo</title><head>bar</head></html>, passing @tagName = "title" will return foo, and @tagName
+   For example, if your \@param element looks like <html><title>foo</title><head>bar</head></html>, passing \@tagName = "title" will return foo, and \@tagName
    = "head" returns bar
    Returns empty string if tag is not found.
 */
 QString getSubTagContent(const QDomElement &element, const QString &tagName);
 
-/** @brief Returns the direct children of given @element whose tag name matches given @param tagName
+/** @brief Returns the direct children of given \@element whose tag name matches given \@param tagName. 
    This is an alternative to QDomElement::elementsByTagName which returns also non-direct children
 */
 QVector<QDomNode> getDirectChildrenByTagName(const QDomElement &element, const QString &tagName);
 
-/** @brief Returns the content of a children tag of @param element, which respects the following conditions :
-   - Its type is @param tagName
-   - It as an attribute named @param attribute with value @param value
+/** @brief Returns the content of a children tag of \@param element, which respects the following conditions :
+   - Its type is \@param tagName
+   - It as an attribute named \@param attribute with value \@param value
+
    For example, if your element is <html><param val="foo">bar</param></html>, you can retrieve "bar" with parameters: tagName="param", attribute="val", and
-   value="foo" Returns @param defaultReturn when nothing is found. The methods returns the first match found, so make sure there can't be more than one. If
-   @param directChildren is true, only immediate children of the node are considered
+   value="foo" Returns \@param defaultReturn when nothing is found. The methods returns the first match found, so make sure there can't be more than one. If
+   \@param directChildren is true, only immediate children of the node are considered
 */
 QString getTagContentByAttribute(const QDomElement &element, const QString &tagName, const QString &attribute, const QString &value,
                                  const QString &defaultReturn = QString(), bool directChildren = true);
