@@ -139,9 +139,14 @@ TEST_CASE("Simple Mix", "[SameTrackMix]")
         state0();
         REQUIRE(timeline->mixClip(cid4));
         state2();
-        // Move clip inside mix zone, should resize the mix
-        REQUIRE(timeline->requestClipMove(cid4, tid2, 506));
-        REQUIRE(timeline->getTrackById_const(tid2)->mixCount() == 1);
+        
+        // Move right clip to the left, should fail
+        REQUIRE(timeline->requestClipMove(cid4, tid2, 506) == false);
+        
+        // Move clip inside mix zone, should delete the mix
+        REQUIRE(timeline->requestClipMove(cid4, tid2, 509));
+        REQUIRE(timeline->getTrackById_const(tid2)->mixCount() == 0);
+        REQUIRE(timeline->m_allClips[cid4]->getSubPlaylistIndex() == 0);
         undoStack->undo();
         state2();
         // Move clip outside mix zone, should delete the mix and move it back to playlist 0
@@ -166,14 +171,21 @@ TEST_CASE("Simple Mix", "[SameTrackMix]")
         state0();
         REQUIRE(timeline->mixClip(cid4));
         state2();
-        // Move clip inside mix zone, should resize the mix
-        REQUIRE(timeline->requestClipMove(cid3, tid2, 502));
-        REQUIRE(timeline->getTrackById_const(tid2)->mixCount() == 1);
+        
+        // Move left clip to the right, should silently fail
+        REQUIRE(timeline->requestClipMove(cid3, tid2, 502, true, true, false) == false);
+        REQUIRE(timeline->getClipPosition(cid3) == 500);
+        
+        // Move clip inside mix zone, should delete the mix
+        REQUIRE(timeline->requestClipMove(cid3, tid2, 499));
+        REQUIRE(timeline->getTrackById_const(tid2)->mixCount() == 0);
+        REQUIRE(timeline->m_allClips[cid4]->getSubPlaylistIndex() == 0);
         undoStack->undo();
         state2();
         // Move clip outside mix zone, should delete the mix
         REQUIRE(timeline->requestClipMove(cid3, tid2, 450));
         REQUIRE(timeline->getTrackById_const(tid2)->mixCount() == 0);
+        REQUIRE(timeline->m_allClips[cid4]->getSubPlaylistIndex() == 0);
         undoStack->undo();
         state2();
         // Move clip to another track, should delete mix
@@ -245,9 +257,9 @@ TEST_CASE("Simple Mix", "[SameTrackMix]")
         REQUIRE(timeline->mixClip(cid2));
         //state1();
         // Move clip inside mix zone, should resize the mix
-        REQUIRE(timeline->requestClipMove(cid2, tid2, 101));
-        REQUIRE(timeline->getTrackById_const(tid3)->mixCount() == 1);
-        REQUIRE(timeline->getTrackById_const(tid2)->mixCount() == 1);
+        REQUIRE(timeline->requestClipMove(cid2, tid2, 105));
+        REQUIRE(timeline->getTrackById_const(tid3)->mixCount() == 0);
+        REQUIRE(timeline->getTrackById_const(tid2)->mixCount() == 0);
         undoStack->undo();
         state1();
         // Move clip outside mix zone, should delete the mix
